Hello,

find attached a straightforward patch fixing these typos:

halfs --> halves
paramters --> parameters
Unkown --> Unknown
endianess --> endianness

thanks, cu andreas

-- 
You received this message because you are subscribed to the Google Groups 
"Hugin and other free panoramic software" group.
A list of frequently asked questions is available at: 
http://wiki.panotools.org/Hugin_FAQ
To post to this group, send email to [email protected]
To unsubscribe from this group, send email to 
[email protected]
For more options, visit this group at http://groups.google.com/group/hugin-ptx
diff -r cf448fb7ae07 ChangeLog
--- a/ChangeLog	Fri Sep 17 18:31:00 2010 +0200
+++ b/ChangeLog	Sat Sep 18 13:12:40 2010 +0200
@@ -2046,7 +2046,7 @@
 2010-01-21  tmodes  <[email protected]>
 
 	* src/hugin_base/panodata/PanoramaOptions.cpp:
-	Some internal improvements for reset of projection paramters
+	Some internal improvements for reset of projection parameters
 	[454ea5bbae64]
 
 2010-01-20  allardkatan  <[email protected]>
diff -r cf448fb7ae07 doc/releases/hugin-2010.2.0_beta1.txt
--- a/doc/releases/hugin-2010.2.0_beta1.txt	Fri Sep 17 18:31:00 2010 +0200
+++ b/doc/releases/hugin-2010.2.0_beta1.txt	Sat Sep 18 13:12:40 2010 +0200
@@ -1782,7 +1782,7 @@
 2010-01-21  tmodes  <[email protected]>
 
 	* src/hugin_base/panodata/PanoramaOptions.cpp:
-	Some internal improvements for reset of projection paramters
+	Some internal improvements for reset of projection parameters
 	[454ea5bbae64]
 
 2010-01-20  allardkatan  <[email protected]>
diff -r cf448fb7ae07 src/foreign/vigra/vigra/accessor.hxx
--- a/src/foreign/vigra/vigra/accessor.hxx	Fri Sep 17 18:31:00 2010 +0200
+++ b/src/foreign/vigra/vigra/accessor.hxx	Sat Sep 18 13:12:40 2010 +0200
@@ -535,7 +535,7 @@
 
 /** \brief Accessor for one component of a vector.
 
-    This works like VectorComponentAccessor, only the template paramters differ: 
+    This works like VectorComponentAccessor, only the template parameters differ: 
     Here, we need a vector accessor type , wheras VectorComponentAccessor requires a vector type.
 
     <b>Usage:</b>
diff -r cf448fb7ae07 src/foreign/vigra/vigra_impex/tiff.cxx
--- a/src/foreign/vigra/vigra_impex/tiff.cxx	Fri Sep 17 18:31:00 2010 +0200
+++ b/src/foreign/vigra/vigra_impex/tiff.cxx	Sat Sep 18 13:12:40 2010 +0200
@@ -470,7 +470,7 @@
                 unitLength = 1/2.54;
                 break;
             default:
-                vigra_fail("Unkown resolution unit");
+                vigra_fail("Unknown resolution unit");
             }
         }
 
diff -r cf448fb7ae07 src/tools/vig_optimize.cpp
--- a/src/tools/vig_optimize.cpp	Fri Sep 17 18:31:00 2010 +0200
+++ b/src/tools/vig_optimize.cpp	Sat Sep 18 13:12:40 2010 +0200
@@ -63,7 +63,7 @@
          << "  -p n      Number of points to extract" << std::endl
        // random points is default, all points was only implemented for testing purposes
        // << "  -r        Extract random point (faster, but less accurate)" << std::endl
-         << "  -s level  Work on downscaled images, every step halfs width and height" << std::endl
+         << "  -s level  Work on downscaled images, every step halves width and height" << std::endl
          << "  -h        Display help (this text)" << std::endl
          << std::endl
          << " Expert and debugging options:" << std::endl
@@ -228,7 +228,7 @@
 
     // Ensure photometric parameters are selected for optimizaion
     if (!hasphotometricParams(pano)) {
-        cerr << "ERROR:no photometric paramters were selected for optimization" << endl;
+        cerr << "ERROR:no photometric parameters were selected for optimization" << endl;
         cerr << "please update 'v' line in .pto script and try again." << endl;
         return 1;
     }

Reply via email to
diff -r cf448fb7ae07 src/foreign/vigra/vigra_impex/viff.cxx
--- a/src/foreign/vigra/vigra_impex/viff.cxx	Fri Sep 17 18:31:00 2010 +0200
+++ b/src/foreign/vigra/vigra_impex/viff.cxx	Sat Sep 18 13:12:40 2010 +0200
@@ -363,13 +363,13 @@
         vigra_precondition( stream.get() == XV_IMAGE_VER_NUM,
                             "file format version unsupported" );
 
         // check the endianess
         const char machine_dep = stream.get();
         if ( machine_dep == VFF_DEP_BIGENDIAN )
             bo.set("big endian");
         else if ( machine_dep == VFF_DEP_LITENDIAN )
             bo.set("little endian");
-        else vigra_fail( "endianess unsupported" );
+        else vigra_fail( "endianness unsupported" );
 
         // skip the comments
         stream.seekg( 0x208, std::ios::beg );
@@ -363,13 +363,13 @@
                             "file format version unsupported" );
 
-        // check the endianess
+        // check the endianness
         const char machine_dep = stream.get();
         if ( machine_dep == VFF_DEP_BIGENDIAN )